import enum
from transformers import pipeline


MODEL_CKPT = "papluca/xlm-roberta-base-language-detection"


class Language(enum.Enum):
    ENGLISH = 'en'
    RUSSIAN = 'ru'
    UNKNOWN = 'unknown'


def detect_language(text: str) -> Language:
    pipe = pipeline("text-classification", model=MODEL_CKPT)
    result = pipe(text, top_k=1, truncation=True)
    lang = result[0]['label']
    score = result[0]['score']
    if score <= 0.5:
        return Language.UNKNOWN

    if lang == 'ru':
        return Language.RUSSIAN

    if lang == 'en':
        return Language.ENGLISH

    return Language.UNKNOWN


if __name__ == '__main__':
    texts = [
        'featuring a shower , private bathrooms also come with towels .',
        'в вашем распоряжении собственная ванная комната с душем и полотенцами .',
        'featuring a shower , private bathrooms also come with towels ПРИВЕТ'
    ]
    for text in texts:
        language = detect_language(text)
        print(f'{language.value}: {text}')
