import random
from faker import Faker
from django.core.management.base import BaseCommand
from job.models import Employee, Vacancy, Questions

fake = Faker()

class Command(BaseCommand):
    help = 'Generate random data for Employee, Vacancy, and Questions models'

    def handle(self, *args, **kwargs):
        self.generate_employees()
        self.generate_vacancies()
        self.generate_questions()
        self.stdout.write(self.style.SUCCESS('Data generation completed.'))

    def generate_employees(self):
        self.stdout.write('Generating Employee data...')
        for _ in range(10):
            Employee.objects.create(
                first_name=fake.first_name(),
                last_name=fake.last_name(),
                father_name=fake.last_name(),
                date_of_birth=fake.date_of_birth(),
                gender=random.choice(['M', 'F']),
                email=fake.email(),
                phone_number=fake.phone_number(),
                address=fake.address()
            )
        self.stdout.write(self.style.SUCCESS('Employee data generated successfully.'))

    def generate_vacancies(self):
        self.stdout.write('Generating Vacancy data...')
        for _ in range(25):
            Vacancy.objects.create(
                role=random.choice(['creator', 'editor', 'operator']),
                years_of_experience=random.randint(1, 10),
                proficiency=fake.text(),
                problem_solving=fake.text(),
                skills=fake.text(),
                availability=fake.text(),
                motivation=fake.text(),
                full_time=random.choice([True, False]),
                cv_link=fake.url()
            )
        self.stdout.write(self.style.SUCCESS('Vacancy data generated successfully.'))

    def generate_questions(self):
        self.stdout.write('Generating Questions data...')
        for _ in range(25):
            Questions.objects.create(
                email=fake.email(),
                vacancy_question=fake.text(),
                agency_question=fake.text()
            )
        self.stdout.write(self.style.SUCCESS('Questions data generated successfully.'))

cmd = Command()
cmd.handle()