from django.db import models
from django.core.validators import RegexValidator

class Employee(models.Model):
    GENDER_CHOICES = [
        ('M', 'Мужчина'),
        ('F', 'Женщина')
    ]

    first_name = models.CharField(max_length=50, verbose_name='Имя')
    last_name = models.CharField(max_length=50, verbose_name='Фамилия')
    father_name = models.CharField(max_length=50, verbose_name='Отчество (при наличии)', blank=True, default='')
    date_of_birth = models.DateField(verbose_name="Дата рождения")
    gender = models.CharField(max_length=1,verbose_name="Пол", choices=GENDER_CHOICES)
    email = models.EmailField(unique=True)
    phone_regex = RegexValidator(regex=r'^\+?7?\d{10,15}$', message="Номер телефона должен быть в формате +71234567890.")
    phone_number = models.CharField(max_length=15, blank=True, null=True, verbose_name="Номер телефона", validators=[phone_regex])
    address = models.TextField(blank=True, null=True)

class Vacancy(models.Model):
    ROLE_CHOICES = [
        ('creator', 'Креатор'),
        ('editor', 'Монтажер'),
        ('operator', 'Оператор'),
    ]
    role = models.CharField(verbose_name="Вакансия", choices=ROLE_CHOICES, max_length=10)
    years_of_experience = models.IntegerField(verbose_name="Стаж работы (в годах)")
    proficiency = models.TextField(verbose_name="Опишите три навыка, которые по вашему мнению важны для работы")
    problem_solving = models.TextField(verbose_name="Опишите последний ваш конфликт и его решение")

    skills = models.TextField(verbose_name="Опишите приложения, которые вы используете для работы")

    availability = models.CharField(verbose_name="В какое время вы работаете?", max_length=255)
    motivation = models.TextField(verbose_name="Опишите, что вас мотивирует")
    full_time = models.BooleanField(verbose_name="Готовы ли вы работать 40 ч в неделю?")
    cv_link = models.URLField(verbose_name="Ссылка на резюме", blank=True, null=True)


class Questions(models.Model):
    email = models.EmailField(unique=True, verbose_name='Почта, на которую прийдет ответ на вопрос')
    vacancy_question = models.TextField(verbose_name="Вопрос по вакансии", null=True, default=None)
    agency_question = models.TextField(verbose_name="Вопрос по деятельности агенства", blank=True, null=True, default=None)
    date = models.DateTimeField(auto_now_add=True, verbose_name="Дата отправки формы")