import datetime
import logging
import sys

from django.shortcuts import render
# Create your views here.
from .forms import VacancyForm, EmployeeForm, QuestionsForm
from .serializers import *
from django.http import HttpResponseRedirect
from .models import * 
from django.http import JsonResponse
from django.db.models import Count
from rest_framework.views import APIView
from rest_framework.response import Response
from rest_framework import status
from job import translator


def thanks(request):
    return render(request, 'job/thanks.html')


def contacts(request):
    formEmployee = EmployeeForm()
    formVacancy = VacancyForm()
    formQuestions = QuestionsForm()
    if request.method == 'POST':
        form_type = request.POST.get("form_type")

        if form_type == 'formEmployee':
            formEmployee = EmployeeForm(request.POST)
            if formEmployee.is_valid():
                formEmployee.save()
                # return
            else:
                print(formEmployee.errors)
        elif form_type == 'formVacancy':
            formVacancy = VacancyForm(request.POST)
            if formVacancy.is_valid():
                formVacancy.save()
                # return
            else:
                print(formVacancy.errors)
        elif form_type == 'formQuestions':
            formQuestions = QuestionsForm(request.POST)
            if formQuestions.is_valid():
                formQuestions.save()
                return HttpResponseRedirect("/job/thanks")
            else:
                print(formQuestions.errors)

    return render(
        request,
        'job/contacts.html',
        {'employee_form': formEmployee, 'vacancy_form': formVacancy, 'questions_form': formQuestions}
    )


def index(request):
    return render(request, 'job/index.html')


def intern(request):
    return render(request, 'job/intern.html')


def aboutteams(request):
    return render(request, 'job/aboutteams.html')


def aboutcompany(request):
    return render(request, 'job/aboutcompany.html')


def vacancies(request):
    return render(request, 'job/vacancies.html')


def faq(request):
    return render(request, 'job/faq.html')


def requirements(request):
    return render(request, 'job/requirements.html')

def stages(request):
    return render(request, 'job/stages.html')

def cases(request):
    return render(request, 'job/cases.html')


def vacancy1(request):
    return render(request, 'job/vacancy1.html')


def vacancy2(request):
    return render(request, 'job/vacancy2.html')


def vacancy3(request):
    return render(request, 'job/vacancy3.html')


def mentoring(request):
    return render(request, 'job/mentoring.html')


def mentoringgroup(request):
    return render(request, 'job/mentoringgroup.html')


def mentoringindiv(request):
    return render(request, 'job/mentoringindiv.html')


def training(request):
    return render(request, 'job/training.html')


def secret(request):
    return render(request, 'job/secret.html')


def help(request):
    return render(request, 'job/help.html')


def age_gender_chart(request):
    gender_data = Employee.objects.values('gender').annotate(count=Count('id'))
    genders = {'F': 'Женщина', 'M': 'Мужчина'}
    labels = [genders[gender['gender']] for gender in gender_data]
    counts = [gender['count'] for gender in gender_data]

    data = {
        'labels': labels,
        'counts': counts,
    }
    return JsonResponse(data)


def сhart(request):
    return render(request, 'job/charts.html')


def experience_full_time_chart(request):
    vacancies = list(Vacancy.objects.values_list('years_of_experience', flat=True))
    employees =  list(Employee.objects.values_list('date_of_birth', flat=True))
    now = datetime.datetime.now()
    minim = min(len(vacancies), len(employees))
    vacancies = vacancies[:minim+1]
    employees = employees[:minim+1]    
    data = [{'x': now.year - emp.year, 'y': vac} for vac, emp in zip(vacancies, employees)]
    return JsonResponse(data, safe=False)


def employee_chart(request):
    male_count = Employee.objects.filter(gender='M').count()
    female_count = Employee.objects.filter(gender='F').count()
    data = [male_count, female_count]
    return JsonResponse(data, safe=False)


def vacancy_chart(request):
    creator_count = Vacancy.objects.filter(role='creator').count()
    editor_count = Vacancy.objects.filter(role='editor').count()
    operator_count = Vacancy.objects.filter(role='operator').count()
    data = [creator_count, editor_count, operator_count]
    return JsonResponse(data, safe=False)


def questions_chart(request):
    data = Questions.objects.annotate(date_count=Count('date')).values('date', 'date_count')
    chart_data = list(data.values())
    
    return JsonResponse(chart_data, safe=False)


def reviews(request):
    return render(request, 'job/reviews.html')


def vacancy_list(request):
    return render(request, 'job/vacancy_list.html')


def vacancy_retrieve(request, pk):
    return render(request, 'job/vacancy_retrieve.html')


def employee_list(request):
    return render(request, 'job/employee_list.html')


def employee_retrieve(request, pk):
    return render(request, 'job/employee_retrieve.html')


# ----------------------------------------------------------------


class VacancyAPIView(APIView):
    @staticmethod
    def translate_vacancy_fields(request):
        request.data['proficiency'] = translator.attentive_translate(request.data['proficiency'])
        request.data['problem_solving'] = translator.attentive_translate(
            request.data['problem_solving']
        )
        request.data['skills'] = translator.attentive_translate(request.data['skills'])
        request.data['motivation'] = translator.attentive_translate(request.data['motivation'])

    @staticmethod
    def get(request, pk=None):
        if not pk:
            vacancies = Vacancy.objects.all()
            serializer = VacancySerializer(vacancies, many=True)
        else:
            vacancies = Vacancy.objects.get(pk=pk)
            serializer = VacancySerializer(vacancies)     
        return Response(serializer.data)

    def post(self, request):
        self.translate_vacancy_fields(request)
        serializer = VacancySerializer(data=request.data)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data, status=status.HTTP_201_CREATED)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)

    def patch(self, request, pk):
        self.translate_vacancy_fields(request)
        vacancy = Vacancy.objects.get(pk=pk)
        serializer = VacancySerializer(vacancy, data=request.data, partial=True)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)

    @staticmethod
    def delete(request, pk):
        vacancy = Vacancy.objects.get(pk=pk)
        vacancy.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)


class EmployeeAPIView(APIView):
    @staticmethod
    def translate_employee_fields(request):
        # there is nothing to translate
        pass

    @staticmethod
    def get(request, pk=None):
        if not pk:
            employees = Employee.objects.all()
            serializer = EmployeeSerializer(employees, many=True)
        else:
            employee = Employee.objects.get(pk=pk)
            serializer = EmployeeSerializer(employee)     
        return Response(serializer.data)

    def post(self, request):
        self.translate_employee_fields(request)
        serializer = EmployeeSerializer(data=request.data)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data, status=status.HTTP_201_CREATED)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)

    def patch(self, request, pk):
        self.translate_employee_fields(request)
        employee = Employee.objects.get(pk=pk)
        serializer = EmployeeSerializer(employee, data=request.data, partial=True)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)

    @staticmethod
    def delete(request, pk):
        employee = Employee.objects.get(pk=pk)
        employee.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)


class QuestionAPIView(APIView):
    @staticmethod
    def translate_question_fields(request):
        request.data['vacancy_question'] = translator.attentive_translate(
            request.data['vacancy_question'],
        )
        request.data['agency_question'] = translator.attentive_translate(
            request.data['agency_question']
        )

    @staticmethod
    def get(request, pk=None):
        if not pk:
            questions = Questions.objects.all()
            serializer = QuestionsSerializer(questions, many=True)
        else:
            questions = Questions.objects.get(pk=pk)
            serializer = QuestionsSerializer(questions)
        return Response(serializer.data)

    def post(self, request):
        self.translate_question_fields(request)
        serializer = QuestionsSerializer(data=request.data)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data, status=status.HTTP_201_CREATED)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)

    def patch(self, request, pk):
        self.translate_question_fields(request)
        vacancy = Questions.objects.get(pk=pk)
        serializer = QuestionsSerializer(vacancy, data=request.data, partial=True)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)

    @staticmethod
    def delete(request, pk):
        vacancy = Questions.objects.get(pk=pk)
        vacancy.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)
